@@ -17,7 +17,7 @@ class CallableInstance(object):
     of the state machine is only know at the __get__ method of the transition,
     since it's a property descriptor.
 
-    To allow concurrency, we cannot store the the current instance in the
+    To allow concurrency, we cannot store the current instance in the
     descriptor, as it permits only one instance to call a transition  at a
     time.
 
@@ -52,23 +52,27 @@ class CallableInstance(object):
 
 
 class Transition(object):
+    """
+    A transition holds reference to the source and destinations states.
+    """
 
-    def __init__(self, source, destination, key=None, validators=None):
-        self.source = source
-        self.destination = destination
-        self.key = key
-        self.validators = validators or []
+    def __init__(self, *states, **options):
+        self.source = states[0]
+        self.destinations = states[1:]
+        self.identifier = options.get('identifier')
+        self.validators = options.get('validators', [])
+        self.on_execute = options.get('on_execute')
 
     def __repr__(self):
-        return "{}({!r}, {!r}, key={!r})".format(
-            type(self).__name__, self.source, self.destination, self.key)
+        return "{}({!r}, {!r}, identifier={!r})".format(
+            type(self).__name__, self.source, self.destinations, self.identifier)
 
     def __or__(self, other):
-        return CombinedTransition(self, other, key=self.key)
+        return CombinedTransition(self, other, identifier=self.identifier)
 
-    def __contribute_to_class__(self, managed, key):
+    def __contribute_to_class__(self, managed, identifier):
         self.managed = managed
-        self.key = key
+        self.identifier = identifier
 
     def __get__(self, instance, owner):
         def callable(*args, **kwargs):
@@ -77,16 +81,28 @@ class Transition(object):
         return CallableInstance(self, func=callable)
 
     def __set__(self, instance, value):
-        # does nothing (not allow overriding)
-        pass
+        "does nothing (not allow overriding)"
+
+    def __call__(self, f):
+        if not callable(f):
+            raise ValueError('Transitions can only be called as method decorators.')
+        self.on_execute = f
+        return self
 
     def _can_run(self, instance):
         return instance.current_state == self.source
 
-    def _run(self, instance, *args, **kwargs):
+    def _verify_can_run(self, instance):
         if not self._can_run(instance):
-            raise LookupError(_("Transition is not supported."))
+            raise LookupError(
+                _("Can't {} when in {}.").format(
+                    self.identifier,
+                    instance.current_state.name
+                )
+            )
 
+    def _run(self, instance, *args, **kwargs):
+        self._verify_can_run(instance)
         self._validate(*args, **kwargs)
         return instance._activate(self, *args, **kwargs)
 
@@ -94,6 +110,43 @@ class Transition(object):
         for validator in self.validators:
             validator(*args, **kwargs)
 
+    def _get_destination(self, result):
+        """
+        A transition can point to one or more destination states.
+        If there is more than 1 state, the transition **must** specify a `on_execution` callback
+        that should return the desired state.
+        """
+        msg_multiple = _('Multiple destinations, you must return the desired state as: '
+                         '`return <State>` or `return <result>, <State>`.')
+
+        if len(self.destinations) == 1:
+            return result, self.destinations[0]
+
+        if result is None:
+            raise ValueError(msg_multiple)
+        elif isinstance(result, State):
+            destination = result
+            result = None
+        else:
+            try:
+                num = len(result)
+            except TypeError:
+                raise ValueError(msg_multiple)
+
+            if num != 2:
+                raise ValueError(msg_multiple)
+
+            result, destination = result
+
+        if not isinstance(destination, State):
+            raise ValueError(msg_multiple)
+
+        if destination not in self.destinations:
+            raise ValueError(
+                _('{} is not a possible destination state.').format(destination.name))
+
+        return result, destination
+
 
 class CombinedTransition(Transition):
 
@@ -103,20 +156,24 @@ class CombinedTransition(Transition):
 
     @property
     def _right(self):
-        return self.destination
+        return self.destinations[0]
 
-    def __contribute_to_class__(self, managed, key):
-        super(CombinedTransition, self).__contribute_to_class__(managed, key)
-        self._left.__contribute_to_class__(managed, key)
-        self._right.__contribute_to_class__(managed, key)
+    def __call__(self, f):
+        result = super(CombinedTransition, self).__call__(f)
+        self._left.on_execute = self.on_execute
+        self._right.on_execute = self.on_execute
+        return result
+
+    def __contribute_to_class__(self, managed, identifier):
+        super(CombinedTransition, self).__contribute_to_class__(managed, identifier)
+        self._left.__contribute_to_class__(managed, identifier)
+        self._right.__contribute_to_class__(managed, identifier)
 
     def _can_run(self, instance):
         return instance.current_state in [self._left.source, self._right.source]
 
     def _run(self, instance, *args, **kwargs):
-        if not self._can_run(instance):
-            raise LookupError(_("Transition is not supported."))
-
+        self._verify_can_run(instance)
         self._validate(*args, **kwargs)
         transition = self._left if instance.current_state == self._left.source else self._right
         return transition._run(instance, *args, **kwargs)
@@ -135,8 +192,8 @@ class State(object):
         return "{}({!r}, identifier={!r}, value={!r}, initial={!r})".format(
             type(self).__name__, self.name, self.identifier, self.value, self.initial)
 
-    def to(self, state):
-        transition = Transition(self, state)
+    def to(self, *states):
+        transition = Transition(self, *states)
         self.transitions.append(transition)
         return transition
 
@@ -161,10 +218,6 @@ def check_state_factory(state):
 
 class StateMachineMetaclass(type):
 
-    @classmethod
-    def __prepare__(cls, name, bases, **kwargs):
-        return OrderedDict()
-
     def __init__(cls, name, bases, attrs):
         super(StateMachineMetaclass, cls).__init__(name, bases, attrs)
         registry.register(cls)
@@ -184,11 +237,19 @@ class StateMachineMetaclass(type):
         cls.states_map = {s.value: s for s in cls.states}
 
 
+class Model(object):
+    state = None
+
+    def __repr__(self):
+        return 'Model(state={})'.format(self.state)
+
+
 class BaseStateMachine(object):
 
-    def __init__(self, model, state_field='state'):
-        self.model = model
+    def __init__(self, model=None, state_field='state', start_value=None):
+        self.model = model if model else Model()
         self.state_field = state_field
+        self.start_value = start_value
 
         self.check()
 
@@ -204,9 +265,6 @@ class BaseStateMachine(object):
         if not self.transitions:
             raise ValueError(_('There are no transitions.'))
 
-        if not self.model:
-            raise ValueError(_('There is no model.'))
-
         initials = [s for s in self.states if s.initial]
         if len(initials) != 1:
             raise ValueError(_('There should be one and only one initial state. '
@@ -214,7 +272,10 @@ class BaseStateMachine(object):
         self.initial_state = initials[0]
 
         if self.current_state_value is None:
-            self.current_state_value = self.initial_state.value
+            if self.start_value:
+                self.current_state_value = self.start_value
+            else:
+                self.current_state_value = self.initial_state.value
 
     @property
     def current_state_value(self):
@@ -223,7 +284,7 @@ class BaseStateMachine(object):
     @current_state_value.setter
     def current_state_value(self, value):
         if value not in self.states_map:
-            raise Exception(_("{!r} is not a valid state value.").format(value))
+            raise ValueError(_("{!r} is not a valid state value.").format(value))
         setattr(self.model, self.state_field, value)
 
     @property
@@ -234,7 +295,7 @@ class BaseStateMachine(object):
     def allowed_transitions(self):
         "get the callable proxy of the current allowed transitions"
         return [
-            getattr(self, t.key)
+            getattr(self, t.identifier)
             for t in self.current_state.transitions if t._can_run(self)
         ]
 
@@ -243,19 +304,23 @@ class BaseStateMachine(object):
         self.current_state_value = value.value
 
     def _activate(self, transition, *args, **kwargs):
-        on_event = getattr(self, 'on_{}'.format(transition.key), None)
-        result = on_event(*args, **kwargs) if callable(on_event) else None
-        self.current_state = transition.destination
+        on_event = getattr(self, 'on_{}'.format(transition.identifier), transition.on_execute)
+        result = on_event(self, *args, **kwargs) if callable(on_event) else None
+
+        result, destination = transition._get_destination(result)
+
+        self.current_state = destination
         return result
 
-    def get_transition(self, transition_key):
-        transition = getattr(self, transition_key, None)
+    def get_transition(self, transition_identifier):
+        transition = getattr(self, transition_identifier, None)
         if not hasattr(transition, 'source') or not callable(transition):
-            raise ValueError('{!r} is not a valid transition key'.format(transition_key))
+            raise ValueError(
+                '{!r} is not a valid transition identifier'.format(transition_identifier))
         return transition
 
-    def run(self, transition_key, *args, **kwargs):
-        transition = self.get_transition(transition_key)
+    def run(self, transition_identifier, *args, **kwargs):
+        transition = self.get_transition(transition_identifier)
         return transition(*args, **kwargs)
 
 
